\name{CheckStability}
\alias{CheckStability}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Tests stability of inferred ICA modes.}
\description{
 Does a correlation test to see which of the inferred ICA modes are reproducible.
}
\usage{
CheckStability(a.best.l, corr.th)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{a.best.l}{List of \code{a.best} objects from \code{mlica} runs.}
  \item{corr.th}{Correlation threshold to use to decide whether a mode
    is reproducible.}
}

\value{
  A list with the following components
  \item{stabM}{Vector of length \code{ncp} giving fraction of elements in
    \code{a.best.l}, for which correlation of the mode is larger than \code{corr.th}.}
  \item{nI}{Number of elements in \code{a.best.l}.}
}
\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}
\examples{
%See documentation of mlica
}
\keyword{cluster}% at least one, from doc/KEYWORDS


\eof
\name{PriorNormPCA}
\alias{PriorNormPCA}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Prior PCA analysis for threshold setting and noise removal}
\description{
  This function performs a simple PCA analysis to aid in threshold
  setting and noise removal.
}
\usage{
PriorNormPCA(X)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{X}{ Data Matrix (need not be normalised). Subsequent ICA seeks
    independent modes as independent distributions with values "down the
    rows".}
    }
\details{This function performs a simple PCA analysis and is used prior
  to application of the main ICA algorithm. The objective of the prior
  PCA is to help determine the dimensionality of a subspace on which
  the further ICA converges. The convention used here is that the rows of \code{X} label
  the space over which independent components are sought. For a typical
  microarray application in which ICA is being used as a generative
  model for gene expression, rows should label genes and columns should
  label samples. If, however, ICA is to be used as an unsupervised
  projection pursuit algorithm, rows should label samples and columns
  genes. For the latter application, the number of genes should be less than the
  number of samples.}
\value{A list with following components:
  \item{X}{Normalised data matrix with the mean of each column set to zero.}
  \item{corr}{Correlation/Covariance data matrix.}
  \item{eig}{Eigenvalue decomposition of Correlation/Covariance matrix.}
  \item{Dx}{Eigenvalues in a diagonal matrix.}
  \item{Ex}{Eigenvectors}
}
\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}
\examples{%See documentation of mlica.R
}
\keyword{cluster}% at least one, from doc/KEYWORDS


\eof
\name{SortModes}
\alias{SortModes}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Sorting of ICA modes}
\description{
 Sorts inferred ICA modes using two criteria: Relative data power or the
 Liebermeister criterion, which is based on a measure that is a weighted
 linear combination of non-gaussianity and data variance measures.
}
\usage{
SortModes(a.best, c.val = 0.25)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{a.best}{The output object of \code{mlica}.}
  \item{c.val}{A parameter to control the relative weight of the two
    measures when using the Liebermeister criterion. Should be between 0
    (pure data variance measure) and 1 (pure non-gaussianity).
    }
}
\value{
  A list with components:
  \item{a.best}{The output of \code{mlica}.}
  \item{rdp}{The relative data power values obtained for each
    independent component.}
  \item{lbm}{The Liebermeister contrast value for each component.}
}
\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}

\examples{
%See documentation for mlica.
}
\keyword{cluster}% at least one, from doc/KEYWORDS


\eof
\name{mlica}
\alias{mlica}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Maximum likelihood implementation of Independent Component Analysis}
\description{
 This function performs ICA using a maximum likelihood framework and
 takes as arguments parameters to control the number of algorithm runs
 and convergence criteria.
}
\usage{
mlica(prNCP, nruns = 10, tol = 1e-04, maxit = 300, fail.th = 5, learn.mu = 1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{prNCP}{ The output object from \code{proposeNCP}.}
  \item{nruns}{ The number of converged algorithm runs sought (function
    returns the best solution according to the log-likelihood value). }
  \item{tol}{ Tolerance level for establishing convergence of run.}
  \item{maxit}{ Maximum number of iterations to allow per run. }
  \item{fail.th}{ A threshold on the number of consecutive runs that
    fail to converge.}
  \item{learn.mu}{ Learning parameter for fixed point algorithm (note
    that this need not be changed since it has already been optimised).}
}
\value{
  A list with following components:
  \item{A}{Estimate of the mixing matrix.}
  \item{B}{Estimate of the inverse mixing matrix.}
  \item{S}{Estimate of the source matrix.}
  \item{X}{Normalised data matrix.}
  \item{ncp}{Number of independent components.}
  \item{NC}{Binary number specifying whether best run converged or
    not.(=1 indicates convergence,=0 indicates no convergence).}
  \item{LL}{Log likelihood value of best run.}
}
\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}

\examples{
% Simulate data ( Data is matrix of 60 "samples" and 1000 "genes"
% Use mixture of 5 independent components, each IC is mixture of two gaussians.)
data(simMAdata);
% Prior PCA and subspace selection
dataX <- simMAdata[[1]];
prPCA <- PriorNormPCA(dataX);
prNCP <- proposeNCP(prPCA,0.1);
% Multiple repeated runs to check stability of best inferred runs
a.best.l <- list();
for( i in 1:5){
 % selecting the best out of nruns runs
 a.best.l[[i]] <- mlica(prNCP,nruns=10);
}
% checking stability of best runs.
checkICA <- CheckStability(a.best.l,0.7);
% checking inferred ICA modes
sourceS <- simMAdata[[3]];
print(cor(a.best.l[[1]]$S,sourceS));
% Sort modes
sModes <- SortModes(a.best.l[[1]],c.val=0.5);
}
\keyword{cluster}% at least one, from doc/KEYWORDS


\eof
\name{mlicaMAIN}
\alias{mlicaMAIN}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Main engine function that implements the fixed point algorithm
  for maximum likelihood inference of ICA modes.}
\description{
 See references for detailed description.
}
\usage{
mlicaMAIN(prNCP, tol = 1e-04, maxit = 300, mu = 1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{prNCP}{The output object of \code{proposeNCP}.}
  \item{tol}{Tolerance level for convergence.}
  \item{maxit}{Maximum number of iterations to allow for convergence.}
  \item{mu}{Learning paramter for fixed point algorithm. This has
    already been optimised.}
}
\value{
  A list with following components:
  \item{A}{Estimate of the mixing matrix.}
  \item{B}{Estimate of the inverse mixing matrix.}
  \item{S}{Estimate of the source matrix.}
  \item{X}{Normalised data matrix.}
  \item{ncp}{Number of independent components.}
  \item{NC}{Binary number specifying whether best run converged,0, or
    not,1.}
  \item{LL}{Log likelihood value of best run.}
}
\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}
\examples{%See documentation for mlica.R
}
\keyword{internal}% __ONLY ONE__ keyword per line

\eof
\name{proposeNCP}
\alias{proposeNCP}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Number of independent components proposal function}
\description{
 This function takes the output of \code{PriorNormPCA} and returns for
 a given threshold the number of components to be inferred for
 subsequent ICA.
}
\usage{
proposeNCP(prPCA, thresh = 0.1)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{prPCA}{The output object from \code{PriorNormPCA}.}
  \item{thresh}{Threshold on eigenvalues.}
}
\value{A list with following components:
  \item{X}{Normalised data matrix.}
  \item{x}{Normalised data matrix projected onto selected subspace.}
  \item{pEx}{Selected eigenvectors defining subspace for projection.}
  \item{pCorr}{Projected correlation matrix.}
  \item{ncp}{The dimension of the selected subspace(=number of
    independent components to be inferred with subsequent ICA).}
}

\author{Andrew Teschendorff \email{aet21@cam.ac.uk}}
\references{
  \item{1}{Hyvaerinen A., Karhunen J., and Oja E.: \emph{Independent Component
    Analysis}, John Wiley and Sons, New York, (2001).}
  \item{2}{Kreil D. and MacKay D. (2003): \emph{Reproducibility Assessment of
    Independent Component Analysis of Expression Ratios from DNA
    microarrays}, Comparative and Functional Genomics \bold{4} (3),300--317.}
  \item{3}{Liebermeister W. (2002): \emph{Linear Modes of gene
      expression determined by independent component analysis}, Bioinformatics \bold{18}, no.1, 51--60.}
}
\examples{%See documentation of mlica.R
}
\keyword{cluster}% at least one, from doc/KEYWORDS


\eof
\name{simMAdata}
\docType{data}
\alias{simMAdata}
\title{Simulated Microarray data for testing purposes}
\description{
  This data set contains a mock microarray data set of 1000 genes and 60
  samples where the data has been generated from an underlying
  Independent Component Analysis model of 5 supergaussian modes.
}
\usage{data(simMAdata)}
\format{A list with three components. First, second and third components
  are the data matrix, mixing matrix and source matrix, respectively.}
\references{
  Hyvaerinen A., Karhunen J. and Oja E. (2001) \emph{Independent
    Component Analysis}. New York: Wiley.
}
\keyword{datasets}

\eof
